lastError property
Information about the last error that the data source encountered, if any.
This property should be updated whenever the data source encounters a problem, even if it does not cause the state to change. For instance, if a stream connection fails and the state changes to DataSourceState.interrupted, and then subsequent attempts to restart the connection also fail, the state will remain DataSourceState.interrupted but the error information will be updated each time-- and the last error will still be reported in this property even if the state later becomes DataSourceState.valid.
Implementation
final DataSourceStatusErrorInfo? lastError;