stateSince property
The date/time that the value of State most recently changed.
The meaning of this depends on the current state:
-
For DataSourceState.initializing, it is the time that the SDK started initializing.
-
For DataSourceState.valid, it is the time that the data source most recently entered a valid state, after previously having been
DataSourceStatus.initializingor an invalid state such as DataSourceState.interrupted. -
For DataSourceState.interrupted, it is the time that the data source most recently entered an error state, after previously having been DataSourceState.valid.
-
For DataSourceState.shutdown, it is the time that the data source encountered an unrecoverable error or that the SDK was explicitly shut down.
-
For DataSourceState.networkUnavailable or DataSourceState.backgroundDisabled, it is the time that the SDK switched off the data source after detecting one of those conditions.
Implementation
final DateTime stateSince;