Constructors
LDConfig (String sdkCredential , AutoEnvAttributes autoEnvAttributes , {ApplicationInfo ? applicationInfo , HttpProperties ? httpProperties , ServiceEndpoints? serviceEndpoints , EventsConfig ? events , PersistenceConfig ? persistence , bool ? offline , LDLogger ? logger , DataSourceConfig ? dataSourceConfig , bool ? allAttributesPrivate , List <String > ? globalPrivateAttributes , ApplicationEvents ? applicationEvents , List <Hook > ? hooks , List <Plugin > ? plugins })
sdkCredential set the credential for the SDK. This can be either a
mobile key or a client-side ID depending on the build configuration.
Refer to CredentialSource.fromEnvironment for information about
selecting the correct key during build time.
Properties
allAttributesPrivate
→ bool
Whether all context attributes (except the context key) should be marked
as private, and not sent to LaunchDarkly in analytics events.
final inherited
applicationEvents
↔ ApplicationEvents
Configuration which affects how the SDK responds to events affecting
the application.
getter/setter pair
applicationInfo
→ ApplicationInfo ?
Information about the application the LaunchDarkly SDK is running in.
This is optional.
final inherited
autoEnvAttributes
→ AutoEnvAttributes
Controls the collection of automatic environment attributes.
final inherited
dataSourceConfig
→ DataSourceConfig
Settings for SDK data sources.
final inherited
events
→ EventsConfig
Configuration for analytics and diagnostic events.
final inherited
globalPrivateAttributes
→ List <String >
A list of attribute references that will be marked private.
final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
hooks
→ UnmodifiableListView <Hook > ?
An initial list of hooks.
final inherited
httpProperties
→ HttpProperties
Common http configuration which will apply to all http requests made
by the SDK. As different platforms have different constraints, and the
SDK adds its own configuration (additional headers for instance), not
all settings are guaranteed to apply to all connections on all platforms.
final inherited
logger
→ LDLogger
The logger the SDK will use. By default the logger will log using print
and will include info level log messages.
final inherited
offline
→ bool
Disables all network calls from the LaunchDarkly client.
final inherited
persistence
→ PersistenceConfig
Configuration for managing SDK persistence. The SDK persists things such
as anonymous context keys and flag configuration.
final inherited
plugins
↔ List <Plugin > ?
A list of plugins to be used with the SDK.
getter/setter pair
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
sdkCredential
→ String
The credential the SDK should use.
final inherited
serviceEndpoints
→ ServiceEndpoints
Specifies the base service URIs used by SDK components.
final inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
launchdarkly_flutter_client_sdk 4.19.0