operator == method

  1. @override
bool operator ==(
  1. Object other
)
override

Determine if two contexts are equal.

Note that all invalid contexts are equal. If a context cannot be built, because it contains invalid data, then it does not contain data which differentiates it from other invalid contexts. It is not generally meaningful to compare invalid contexts.

Implementation

@override
bool operator ==(Object other) =>
    identical(this, other) ||
    other is LDContext &&
        attributesByKind.equals(other.attributesByKind) &&
        valid == other.valid;