PollingConfig class final

Constructors

PollingConfig({Duration? pollingInterval})
pollingInterval controls the interval between polling requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
pollingInterval Duration
The current polling interval, if less than min, then the min will be used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited